/********************************************************************************
** Form generated from reading UI file 'taskfontsbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TASKFONTSBASE_H
#define UI_TASKFONTSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KFontChooser"

QT_BEGIN_NAMESPACE

class Ui_TaskFontsBase
{
public:
    QGridLayout *gridLayout;
    KFontChooser *kcfg_taskFont;

    void setupUi(QWidget *TaskFontsBase)
    {
        if (TaskFontsBase->objectName().isEmpty())
            TaskFontsBase->setObjectName("TaskFontsBase");
        TaskFontsBase->resize(494, 406);
        gridLayout = new QGridLayout(TaskFontsBase);
        gridLayout->setObjectName("gridLayout");
        kcfg_taskFont = new KFontChooser(TaskFontsBase);
        kcfg_taskFont->setObjectName("kcfg_taskFont");

        gridLayout->addWidget(kcfg_taskFont, 0, 0, 1, 1);


        retranslateUi(TaskFontsBase);

        QMetaObject::connectSlotsByName(TaskFontsBase);
    } // setupUi

    void retranslateUi(QWidget *TaskFontsBase)
    {
#if QT_CONFIG(tooltip)
        kcfg_taskFont->setToolTip(tr2i18n("Change the font of the numbers", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)TaskFontsBase;
    } // retranslateUi

};

namespace Ui {
    class TaskFontsBase: public Ui_TaskFontsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TASKFONTSBASE_H

