/****************************************************************************
** Meta object code from reading C++ file 'MainQtWidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kbruch-26.04.3/src/MainQtWidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainQtWidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MainQtWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto MainQtWidget::qt_create_metaobjectdata<qt_meta_tag_ZN12MainQtWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainQtWidget",
        "OperationsCheck",
        "",
        "SelectArithmetic",
        "SelectComparison",
        "SelectConversion",
        "SelectMixedNumbers",
        "SelectFactorization",
        "SelectPercentage",
        "ReducedFormCheckSlot",
        "QuestionMixedCheckSlot",
        "AnswerMixedCheckSlot",
        "AdditionCheckSlot",
        "SubtractionCheckSlot",
        "MultiplicationCheckSlot",
        "DivisionCheckSlot",
        "NrOfTermsBoxSlot",
        "MaxMainDenominatorBoxSlot",
        "newTask",
        "slotPrefs",
        "slotApplySettings",
        "slotAboutToShowPage",
        "goBack"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'OperationsCheck'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'SelectArithmetic'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SelectComparison'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SelectConversion'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SelectMixedNumbers'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SelectFactorization'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SelectPercentage'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ReducedFormCheckSlot'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'QuestionMixedCheckSlot'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AnswerMixedCheckSlot'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'AdditionCheckSlot'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'SubtractionCheckSlot'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'MultiplicationCheckSlot'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'DivisionCheckSlot'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'NrOfTermsBoxSlot'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'MaxMainDenominatorBoxSlot'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'newTask'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPrefs'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotApplySettings'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAboutToShowPage'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainQtWidget, qt_meta_tag_ZN12MainQtWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainQtWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MainQtWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MainQtWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MainQtWidgetE_t>.metaTypes,
    nullptr
} };

void MainQtWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainQtWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->OperationsCheck();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->SelectArithmetic(); break;
        case 2: _t->SelectComparison(); break;
        case 3: _t->SelectConversion(); break;
        case 4: _t->SelectMixedNumbers(); break;
        case 5: _t->SelectFactorization(); break;
        case 6: _t->SelectPercentage(); break;
        case 7: _t->ReducedFormCheckSlot(); break;
        case 8: _t->QuestionMixedCheckSlot(); break;
        case 9: _t->AnswerMixedCheckSlot(); break;
        case 10: _t->AdditionCheckSlot(); break;
        case 11: _t->SubtractionCheckSlot(); break;
        case 12: _t->MultiplicationCheckSlot(); break;
        case 13: _t->DivisionCheckSlot(); break;
        case 14: _t->NrOfTermsBoxSlot(); break;
        case 15: _t->MaxMainDenominatorBoxSlot(); break;
        case 16: _t->newTask(); break;
        case 17: _t->slotPrefs(); break;
        case 18: _t->slotApplySettings(); break;
        case 19: _t->slotAboutToShowPage(); break;
        case 20: _t->goBack(); break;
        default: ;
        }
    }
}

const QMetaObject *MainQtWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainQtWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MainQtWidgetE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainQtWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
